aboutsummaryrefslogtreecommitdiff
path: root/src/geometry/mod.rs
diff options
context:
space:
mode:
authorSébastien Crozet <sebcrozet@dimforge.com>2024-05-04 17:51:15 +0200
committerSébastien Crozet <sebastien@crozet.re>2024-05-05 16:17:39 +0200
commit7565e5e4efb56bb8ba987c251b932bffc15a40c8 (patch)
tree037acb54bcb7384811214f966bb5e5680ac17d5c /src/geometry/mod.rs
parentdbefeb04186226536ec7f4f248c71f056265916a (diff)
downloadrapier-7565e5e4efb56bb8ba987c251b932bffc15a40c8.tar.gz
rapier-7565e5e4efb56bb8ba987c251b932bffc15a40c8.tar.bz2
rapier-7565e5e4efb56bb8ba987c251b932bffc15a40c8.zip
chore: update to the latest parry api
Diffstat (limited to 'src/geometry/mod.rs')
-rw-r--r--src/geometry/mod.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/geometry/mod.rs b/src/geometry/mod.rs
index be2d9d5..1eaad79 100644
--- a/src/geometry/mod.rs
+++ b/src/geometry/mod.rs
@@ -51,8 +51,8 @@ pub type Ray = parry::query::Ray;
pub type RayIntersection = parry::query::RayIntersection;
/// The projection of a point on a collider.
pub type PointProjection = parry::query::PointProjection;
-/// The time of impact between two shapes.
-pub type TOI = parry::query::TOI;
+/// The result of a shape-cast between two shapes.
+pub type ShapeCastHit = parry::query::ShapeCastHit;
/// The default broad-phase implementation recommended for general-purpose usage.
pub type DefaultBroadPhase = BroadPhaseMultiSap;